@@ -11,7 +11,7 @@ from equinox.custom_types import Array
 from ...utils import load_torch_weights, MODEL_URLS
 
 
-class Fire(eqx.Module):
+class _Fire(eqx.Module):
     inplanes: int
     squeeze: nn.Conv2d
     squeeze_activation: nn.Lambda
@@ -85,17 +85,17 @@ class SqueezeNet(eqx.Module):
                 [
                     nn.Conv2d(3, 96, kernel_size=7, stride=2, key=keys[0]),
                     nn.Lambda(jnn.relu),
-                    nn.MaxPool2d(kernel_size=3, stride=2),
-                    Fire(96, 16, 64, 64, key=keys[1]),
-                    Fire(128, 16, 64, 64, key=keys[2]),
-                    Fire(128, 32, 128, 128, key=keys[3]),
-                    nn.MaxPool2d(kernel_size=3, stride=2),
-                    Fire(256, 32, 128, 128, key=keys[4]),
-                    Fire(256, 48, 192, 192, key=keys[5]),
-                    Fire(384, 48, 192, 192, key=keys[6]),
-                    Fire(384, 64, 256, 256, key=keys[7]),
-                    nn.MaxPool2d(kernel_size=3, stride=2),
-                    Fire(512, 64, 256, 256, key=keys[8]),
+                    nn.MaxPool2d(kernel_size=3, stride=2, use_ceil=True),
+                    _Fire(96, 16, 64, 64, key=keys[1]),
+                    _Fire(128, 16, 64, 64, key=keys[2]),
+                    _Fire(128, 32, 128, 128, key=keys[3]),
+                    nn.MaxPool2d(kernel_size=3, stride=2, use_ceil=True),
+                    _Fire(256, 32, 128, 128, key=keys[4]),
+                    _Fire(256, 48, 192, 192, key=keys[5]),
+                    _Fire(384, 48, 192, 192, key=keys[6]),
+                    _Fire(384, 64, 256, 256, key=keys[7]),
+                    nn.MaxPool2d(kernel_size=3, stride=2, use_ceil=True),
+                    _Fire(512, 64, 256, 256, key=keys[8]),
                 ]
             )
         elif version == "1_1":
@@ -103,17 +103,17 @@ class SqueezeNet(eqx.Module):
                 [
                     nn.Conv2d(3, 64, kernel_size=3, stride=2, key=keys[0]),
                     nn.Lambda(jnn.relu),
-                    nn.MaxPool2d(kernel_size=3, stride=2),
-                    Fire(64, 16, 64, 64, key=keys[1]),
-                    Fire(128, 16, 64, 64, key=keys[2]),
-                    nn.MaxPool2d(kernel_size=3, stride=2),
-                    Fire(128, 32, 128, 128, key=keys[3]),
-                    Fire(256, 32, 128, 128, key=keys[4]),
-                    nn.MaxPool2d(kernel_size=3, stride=2),
-                    Fire(256, 48, 192, 192, key=keys[5]),
-                    Fire(384, 48, 192, 192, key=keys[6]),
-                    Fire(384, 64, 256, 256, key=keys[7]),
-                    Fire(512, 64, 256, 256, key=keys[8]),
+                    nn.MaxPool2d(kernel_size=3, stride=2, use_ceil=True),
+                    _Fire(64, 16, 64, 64, key=keys[1]),
+                    _Fire(128, 16, 64, 64, key=keys[2]),
+                    nn.MaxPool2d(kernel_size=3, stride=2, use_ceil=True),
+                    _Fire(128, 32, 128, 128, key=keys[3]),
+                    _Fire(256, 32, 128, 128, key=keys[4]),
+                    nn.MaxPool2d(kernel_size=3, stride=2, use_ceil=True),
+                    _Fire(256, 48, 192, 192, key=keys[5]),
+                    _Fire(384, 48, 192, 192, key=keys[6]),
+                    _Fire(384, 64, 256, 256, key=keys[7]),
+                    _Fire(512, 64, 256, 256, key=keys[8]),
                 ]
             )
 
@@ -148,9 +148,8 @@ def _squeezenet(version: str, pretrained: bool, **kwargs: Any) -> SqueezeNet:
 
 
 def squeezenet1_0(pretrained: bool = False, **kwargs: Any) -> SqueezeNet:
-    r"""SqueezeNet model architecture from the `"SqueezeNet: AlexNet-level
-    accuracy with 50x fewer parameters and <0.5MB model size"
-    <https://arxiv.org/abs/1602.07360>`_ paper.
+    r"""SqueezeNet model architecture from the [SqueezeNet: AlexNet-level
+    accuracy with 50x fewer parameters and <0.5MB model size](https://arxiv.org/abs/1602.07360) paper.
     The required minimum input size of the model is 21x21.
 
     **Arguments:**
@@ -161,8 +160,8 @@ def squeezenet1_0(pretrained: bool = False, **kwargs: Any) -> SqueezeNet:
 
 
 def squeezenet1_1(pretrained: bool = False, **kwargs: Any) -> SqueezeNet:
-    r"""SqueezeNet 1.1 model from the `official SqueezeNet repo
-    <https://github.com/DeepScale/SqueezeNet/tree/master/SqueezeNet_v1.1>`_.
+    r"""SqueezeNet 1.1 model from the (official SqueezeNet repo)
+    [https://github.com/DeepScale/SqueezeNet/tree/master/SqueezeNet_v1.1].
     SqueezeNet 1.1 has 2.4x less computation and slightly fewer parameters
     than SqueezeNet 1.0, without sacrificing accuracy.
     The required minimum input size of the model is 17x17.
